Public API#
litmap.__version__#
Package version string.
litmap.package_overview()#
Returns a small dictionary describing the package purpose and its core design rule.
litmap.recommended_run_layout()#
Returns a tuple of strings describing the recommended run directory layout.